@@ -6,7 +6,7 @@
 # MD5:   __MD5__
 
 #if osx
-unset DYLD_LIBRARY_PATH
+unset DYLD_LIBRARY_PATH DYLD_FALLBACK_LIBRARY_PATH
 #else
 export OLD_LD_LIBRARY_PATH=$LD_LIBRARY_PATH
 unset LD_LIBRARY_PATH
@@ -17,6 +17,11 @@ if ! echo "$0" | grep '\.sh$' > /dev/null; then
     return 1
 fi
 
+# Export variables to make installer metadata available to pre/post install scripts
+export INSTALLER_NAME="__NAME__"
+export INSTALLER_VER="__VERSION__"
+export INSTALLER_PLAT="__PLAT__"
+
 THIS_DIR=$(DIRNAME=$(dirname "$0"); cd "$DIRNAME"; pwd)
 THIS_FILE=$(basename "$0")
 THIS_PATH="$THIS_DIR/$THIS_FILE"
@@ -43,12 +48,8 @@ Installs __NAME__ __VERSION__
 #if batch_mode
 -i           run install in interactive mode
 #else
-  #if has_license
 -b           run install in batch mode (without manual intervention),
-             it is expected the license terms are agreed upon
-  #else
--b           run install in batch mode (without manual intervention)
-  #endif
+             it is expected the license terms (if any) are agreed upon
 #endif
 -f           no error if install prefix already exists
 -h           print this help message and exit
@@ -443,12 +444,12 @@ printf "Unpacking payload ...\n"
 extract_range $boundary1 $boundary2 | \
     "$CONDA_EXEC" constructor --extract-tarball --prefix "$PREFIX"
 
-"$CONDA_EXEC" constructor --prefix "$PREFIX" --extract-conda-pkgs || exit 1
-
 PRECONDA="$PREFIX/preconda.tar.bz2"
 "$CONDA_EXEC" constructor --prefix "$PREFIX" --extract-tarball < "$PRECONDA" || exit 1
 rm -f "$PRECONDA"
 
+"$CONDA_EXEC" constructor --prefix "$PREFIX" --extract-conda-pkgs || exit 1
+
 #The templating doesn't support nested if statements
 #if has_pre_install
 if [ "$SKIP_SCRIPTS" = "1" ]; then
@@ -551,21 +552,14 @@ if [ "$PYTHONPATH" != "" ]; then
 fi
 
 if [ "$BATCH" = "0" ]; then
+#if initialize_by_default is True
+    DEFAULT=yes
+#else
+    DEFAULT=no
+#endif
+
 #if has_conda
     # Interactive mode.
-  #if osx
-    BASH_RC="$HOME"/.bash_profile
-    DEFAULT=yes
-  #else
-    BASH_RC="$HOME"/.bashrc
-    DEFAULT=no
-  #endif
-  #if initialize_by_default is True
-    DEFAULT=yes
-  #endif
-  #if initialize_by_default is False
-    DEFAULT=no
-  #endif
 
     printf "Do you wish the installer to initialize __NAME__\\n"
     printf "by running conda init? [yes|no]\\n"
@@ -592,6 +586,12 @@ if [ "$BATCH" = "0" ]; then
             *zsh) $PREFIX/bin/conda init zsh ;;
             *) $PREFIX/bin/conda init ;;
         esac
+        if [ -f "$PREFIX/bin/mamba" ]; then
+            case $SHELL in
+                *zsh) $PREFIX/bin/mamba init zsh ;;
+                *) $PREFIX/bin/mamba init ;;
+            esac
+        fi
     fi
     printf "If you'd prefer that conda's base environment not be activated on startup, \\n"
     printf "   set the auto_activate_base parameter to false: \\n"
